@@ -13,8 +13,11 @@ void insthier(void)
   c(bin,  "twoftpd-auth",      -1, -1, 0555);
   c(bin,  "twoftpd-bind-port", -1, -1, 0555);
   c(bin,  "twoftpd-conf",      -1, -1, 0555);
+  c(bin,  "twoftpd-drop",      -1, -1, 0555);
+  c(bin,  "twoftpd-switch",    -1, -1, 0555);
   c(bin,  "twoftpd-xfer",      -1, -1, 0555);
 
   c(man1, "twoftpd-auth.1",    -1, -1, 0444);
+  c(man1, "twoftpd-switch.1",  -1, -1, 0444);
   c(man1, "twoftpd-xfer.1",    -1, -1, 0444);
 }
