@@ -17,7 +17,7 @@
  */
 #include <stdlib.h>
 #include <string.h>
-#include "systime.h"
+#include <systime.h>
 #include <unistd.h>
 #include "twoftpd.h"
 #include "backend.h"
